.. pyexcel-ods3 documentation master file, created by
   sphinx-quickstart on Sun Dec 13 19:50:31  2015-2016 .
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

